# Metamart Graph

This project provides a variety of utilities for exploring your Metamart data lineage graph including support
for counter factual tests to determine the impact of a data change on your infrastructure.
